@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::Shippo;
 # ABSTRACT: A Shippo Perl API wrapper
-our $VERSION = '0.0.7';
+our $VERSION = '0.0.8';
 require WebService::Shippo::Entities;
 require WebService::Shippo::Request;
 require WebService::Shippo::Config;
@@ -41,7 +41,6 @@ our @EXPORT_OK = qw(
     shippo_shipment_list
     shippo_shipment_create
     shippo_shipment_rates
-    shippo_return_shipment_create
     shippo_transaction
     shippo_transaction_list
     shippo_transaction_create
@@ -78,7 +77,6 @@ sub shippo_shipment                   { WebService::Shippo::Shipment->get( @_ )
 sub shippo_shipment_list              { WebService::Shippo::Shipment->all( @_ ) }
 sub shippo_shipment_create            { WebService::Shippo::Shipment->create( @_ ) }
 sub shippo_shipment_rates             { WebService::Shippo::Shipment->rates( @_ ) }
-sub shippo_return_shipment_create     { WebService::Shippo::ReturnShipment->create( @_ ) }
 sub shippo_transaction                { WebService::Shippo::Transaction->get( @_ ) }
 sub shippo_transaction_list           { WebService::Shippo::Transaction->all( @_ ) }
 sub shippo_transaction_create         { WebService::Shippo::Transaction->create( @_ ) }
@@ -121,9 +119,9 @@ WebService::Shippo - A Shippo API Perl Wrapper (coming soon)
 
 =head1 VERSION
 
-0.0.7 
+0.0.8 
 
-Built 2015-10-20 (no more changes until 2015-10-23 - I'm out of town).
+Built 2015-10-24.
 
 =head1 UNDER CONSTRUCTION
 
@@ -139,11 +137,9 @@ see, documentation is rather thin on the ground; that, too, is coming.
     use strict;
     use WebService::Shippo;
     
-    # Following statement is not necessary if SHIPPO_TOKEN is set in
-    # your process environment.
     Shippo->api_key(PRIVATE-AUTH-TOKEN);
     
-    my $address1 = Shippo::Address->create({
+    my $address = Shippo::Address->create(
         object_purpose => 'PURCHASE',
         name           => 'John Smith',
         street1        => '6512 Greene Rd.',
@@ -156,7 +152,7 @@ see, documentation is rather thin on the ground; that, too, is coming.
         country        => 'US',
         email          => 'user@gmail.com',
         metadata       => 'Customer ID 123456'
-    });
+    );
     
     print 'Success with Address 1 : ', $address
     
